summaryrefslogtreecommitdiff
path: root/src/guichan/include/guichan/mouseevent.hpp
diff options
context:
space:
mode:
authorAndrei Karas <akaras@inbox.ru>2011-09-09 19:43:40 +0300
committerAndrei Karas <akaras@inbox.ru>2011-09-09 19:43:40 +0300
commit4484b433abc8f07bcf7d4d22fd946e00b66b078d (patch)
treed8d04c6ea9526b90334e7b0a4abf44e2508a3597 /src/guichan/include/guichan/mouseevent.hpp
parentc1fb0bf9dc98e2a30f33cbbf4f74604b36efbcba (diff)
downloadmv-4484b433abc8f07bcf7d4d22fd946e00b66b078d.tar.gz
mv-4484b433abc8f07bcf7d4d22fd946e00b66b078d.tar.bz2
mv-4484b433abc8f07bcf7d4d22fd946e00b66b078d.tar.xz
mv-4484b433abc8f07bcf7d4d22fd946e00b66b078d.zip
Fix first part of shadow variables/methods errors.
Diffstat (limited to 'src/guichan/include/guichan/mouseevent.hpp')
-rw-r--r--src/guichan/include/guichan/mouseevent.hpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/guichan/include/guichan/mouseevent.hpp b/src/guichan/include/guichan/mouseevent.hpp
index 280d373e6..6f6dc828c 100644
--- a/src/guichan/include/guichan/mouseevent.hpp
+++ b/src/guichan/include/guichan/mouseevent.hpp
@@ -66,10 +66,10 @@ namespace gcn
* Constructor.
*
* @param source The source widget of the mouse event.
* @param isShiftPressed True if shift is pressed, false otherwise.
* @param isControlPressed True if control is pressed, false otherwise.
* @param isAltPressed True if alt is pressed, false otherwise.
* @param isMetaPressed True if meta is pressed, false otherwise.
* @param type The type of the mouse event.
* @param button The button of the mouse event.
* @param x The x coordinate of the event relative to the source widget.
@@ -78,10 +78,10 @@ namespace gcn
* It's set to zero if another button is used.
*/
MouseEvent(Widget* source,
- bool isShiftPressed,
- bool isControlPressed,
- bool isAltPressed,
- bool isMetaPressed,
+ bool shiftPressed,
+ bool controlPressed,
+ bool altPressed,
+ bool metaPressed,
unsigned int type,
unsigned int button,
int x,
@@ -66,10 +66,10 @@ namespace gcn
*
* @param source The source widget of the mouse event.
- * @param isShiftPressed True if shift is pressed, false otherwise.
- * @param isControlPressed True if control is pressed, false otherwise.
- * @param isAltPressed True if alt is pressed, false otherwise.
- * @param isMetaPressed True if meta is pressed, false otherwise.
+ * @param shiftPressed True if shift is pressed, false otherwise.
+ * @param controlPressed True if control is pressed, false otherwise.
+ * @param altPressed True if alt is pressed, false otherwise.
+ * @param metaPressed True if meta is pressed, false otherwise.
* @param type The type of the mouse event.
* @param button The button of the mouse event.